package api

import (
	"fmt"
	"net/http"

	"github.com/gorilla/mux"
)

var apiRootPath string = "/api/v1"

func Init(router *mux.Router) {

	router.HandleFunc(apiRootPath, apiRoot).Methods("GET")

	routerAuth := router.PathPrefix(apiRootPath + "/auth").Subrouter()
	routerPage := router.PathPrefix(apiRootPath + "/page").Subrouter()
	routerUser := router.PathPrefix(apiRootPath + "/user").Subrouter()
	routerTag := router.PathPrefix(apiRootPath + "/tag").Subrouter()

	routerAuth.HandleFunc("", apiAuth)
	routerAuth.HandleFunc("/login", apiAuthLogin)
	routerAuth.HandleFunc("/logout", apiAuthLogout)

	routerPage.HandleFunc("", apiPage)
	routerPage.HandleFunc("/{folder}", apiPageFolder)
	routerPage.HandleFunc("/{folder}/{page}", apiPageFolderPage)
	routerPage.HandleFunc("/{folder}/{page}/content", apiPageFolderPageContent)

	routerUser.HandleFunc("", apiUser)
	routerUser.HandleFunc("/{name}", apiUserName)

	routerTag.HandleFunc("", apiTag)
	routerTag.HandleFunc("/{name}", apiTagName)
}

// API ROOT

func apiRoot(w http.ResponseWriter, r *http.Request) {
	fmt.Fprintf(w, "API ROOT")
}

// API Auth

func apiAuth(w http.ResponseWriter, r *http.Request) {
	fmt.Fprintf(w, "API Auth")
}

func apiAuthLogin(w http.ResponseWriter, r *http.Request) {
	fmt.Fprintf(w, "API Auth Login")
}

func apiAuthLogout(w http.ResponseWriter, r *http.Request) {
	fmt.Fprintf(w, "API Auth Logout")
}

// API Page

func apiPage(w http.ResponseWriter, r *http.Request) {
	fmt.Fprintf(w, "API Page")
}

func apiPageFolder(w http.ResponseWriter, r *http.Request) {
	vars := mux.Vars(r)
	fmt.Fprintf(w, "API Page Folder(%s)", vars["folder"])
}

func apiPageFolderPage(w http.ResponseWriter, r *http.Request) {
	vars := mux.Vars(r)
	fmt.Fprintf(w, "API Page Folder(%s) Page(%s)", vars["folder"], vars["page"])
}

func apiPageFolderPageContent(w http.ResponseWriter, r *http.Request) {
	vars := mux.Vars(r)
	fmt.Fprintf(w, "API Page Folder(%s) Page(%s) Content", vars["folder"], vars["page"])
}

// API User

func apiUser(w http.ResponseWriter, r *http.Request) {
	fmt.Fprintf(w, "API User")
}

func apiUserName(w http.ResponseWriter, r *http.Request) {
	vars := mux.Vars(r)
	fmt.Fprintf(w, "API User Name(%s)", vars["name"])
}

// API Tag

func apiTag(w http.ResponseWriter, r *http.Request) {
	fmt.Fprintf(w, "API Tag")
}

func apiTagName(w http.ResponseWriter, r *http.Request) {
	vars := mux.Vars(r)
	fmt.Fprintf(w, "API Tag Name(%s)", vars["name"])
}
