package config

import (
	"encoding/json"
	"log"
	"os"
)

const CONFIG_FILE_NAME string = "./config.json"
const CONFIG_FILE_DEFAULT_CONF string = `{
    "Database": {
        "Host": "localhost",
        "Port": "3306",
        "Database": "Chromagies",
        "User": "chromagies_user",
        "Password": "12345678"
    },

    "Logger": {
        "Output": "./log.txt"
    },
    "Server": {
        "Port": "12345"
    }
}`

type Database struct {
	Host     string
	Port     string
	Database string
	User     string
	Password string
}

type Logger struct {
	Output string
}

type Server struct {
	IP   string
	Port string
}

type Config struct {
	Database Database
	Logger   Logger
	Server   Server
}

var config Config

func ReadConfigFile() error {
	log.Println("Reading config file")
	file, err := os.Open(CONFIG_FILE_NAME)
	if err != nil {
		log.Println(err)
		return err
	}
	defer file.Close()

	err = json.NewDecoder(file).Decode(&config)
	if err != nil {
		log.Println(err)
		return err
	}

	log.Println("Reading config OK")
	return nil
}

func CreateConfigFile() error {
	log.Println("Creating config file")
	file, err := os.Create(CONFIG_FILE_NAME)
	if err != nil {
		log.Println(err)
		return err
	}

	_, err = file.WriteString(CONFIG_FILE_DEFAULT_CONF)
	if err != nil {
		log.Println(err)
		return err
	}

	return nil
}

func GetConfig() Config {
	return config
}
